pub type PluginMetaFn = extern "C" fn() -> PluginMeta;Expand description
插件元数据函数签名 Note: PluginMeta contains String which is not FFI-safe by default, but we accept this limitation for the plugin ABI design.
pub type PluginMetaFn = extern "C" fn() -> PluginMeta;插件元数据函数签名 Note: PluginMeta contains String which is not FFI-safe by default, but we accept this limitation for the plugin ABI design.